@@ -76,6 +76,7 @@
 #define CTX_EXES  131072          
 #define CTX_CACHED 262144
 #define CTX_ONE_FS 524288
+#define CTX_HIDDEN 1048576
 
 
 #define RESULT_PASS 1
@@ -93,7 +94,7 @@
 
 #define IGNORE -1
 
-#define VERSION "1.10.4"
+#define VERSION "1.12"
 
 
 typedef struct
@@ -120,6 +121,9 @@ char *Targets;
 int Action;
 int Flags;
 int Encoding;  
+int OutputLength;
+int SegmentLength;
+int SegmentChar;
 dev_t StartingFS;
 ListNode *Vars;
 } HashratCtx;
