@@ -55,6 +55,7 @@ int val;
 	memset(Stat, 0, sizeof(struct stat));
   //Pass NULL for stat, because we are only checking for 'net' type paths
   val=FileType(Path, Flags, NULL);
+
   if ((val !=FT_FILE) && (val !=FT_DIR) && (val != FT_LNK))
   {
     return(val);
@@ -73,7 +74,7 @@ void GlobFiles(HashratCtx *Ctx, const char *Path, int FType, ListNode *Dirs)
 {
 char *Tempstr=NULL;
 glob_t Glob;
-int i;
+int i, flags=0;
 struct stat *Stat;
 
 ListClear(Dirs, Destroy);
@@ -90,13 +91,17 @@ switch (FType)
 	break;
 }
 
-Tempstr=MCopyStr(Tempstr,Path,"/*",NULL);
-glob(Tempstr,0,0,&Glob);
+Tempstr=QuoteCharsInStr(Tempstr, Path, "[]*?");
+Tempstr=CatStr(Tempstr,"/*");
+#ifdef GLOB_PERIOD
+if (Ctx->Flags & CTX_HIDDEN) flags |= GLOB_PERIOD;
+#endif
+glob(Tempstr,flags,0,&Glob);
 for (i=0; i < Glob.gl_pathc; i++)
 {
 	if (
-				(strcmp(Glob.gl_pathv[i],".") !=0) &&
-				(strcmp(Glob.gl_pathv[i],"..") !=0)
+				(strcmp(GetBasename(Glob.gl_pathv[i]),".") !=0) &&
+				(strcmp(GetBasename(Glob.gl_pathv[i]),"..") !=0)
 		)
 	{
 		if (Dirs)
@@ -210,12 +215,14 @@ const char *ptr;
 
 		HashFinish(Hash,Ctx->Encoding,RetStr);
 
+		/*
 		ptr=GetVar(Ctx->Vars,"Output:Length");
 		if (StrValid(ptr))
 		{
 			val=atoi(ptr);
 			if ((val > 0) && (StrLen(*RetStr) > val)) (*RetStr)[val]='\0';
 		}
+		*/
 }
 
 
